@@ -6,7 +6,16 @@ from dateutil.relativedelta import relativedelta
 from django.test import TestCase
 from django_mock_queries.query import MockModel
 from edc_utils import get_utcnow
-from edc_visit_schedule.constants import DAY01
+from edc_visit_schedule.constants import (
+    DAY01,
+    DAY03,
+    DAY09,
+    DAY14,
+    WEEK04,
+    WEEK10,
+    WEEK16,
+    WEEK24,
+)
 
 
 class FormValidatorTestMixin:
@@ -33,6 +42,17 @@ class FormValidatorTestMixin:
 
 
 class TestCaseMixin(TestCase):
+    visit_schedule = [
+        DAY01,
+        DAY03,
+        DAY09,
+        DAY14,
+        WEEK04,
+        WEEK10,
+        WEEK16,
+        WEEK24,
+    ]
+
     def setUp(self) -> None:
         """Setup appointment and subject_visit Mock models"""
         self.screening_datetime = get_utcnow() - relativedelta(years=1)
